@@ -1,8 +1,8 @@
-#  File R/zzz.R in package ergm.ego, part of the
-#  Statnet suite of packages for network analysis, https://statnet.org .
+#  File R/zzz.R in package ergm.ego, part of the Statnet suite of packages for
+#  network analysis, https://statnet.org .
 #
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
+#  This software is distributed under the GPL-3 license.  It is free, open
+#  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
 #  Copyright 2015-2025 Statnet Commons
@@ -17,7 +17,7 @@
 
 .onLoad <- function(libname, pkgname){
   # . is used as a placeholder by stantet.common::NVL3().
-  utils::globalVariables(".")
+  utils::globalVariables(c(".", ".data", ".env"))
 
   eval(COLLATE_ALL_MY_CONTROLS_EXPR)
 }
